==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/plugins/Effect/crossfade/translations/crossfade_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EffectCrossfadeFactory</name>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="30"/>
        <source>Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="51"/>
        <source>About Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="52"/>
        <source>Qmmp Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Crossfade Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Overlap:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Effect/crossfade/translations/crossfade_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EffectCrossfadeFactory</name>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="30"/>
        <source>Crossfade Plugin</source>
        <translation>Wtyczka Crossfade</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="51"/>
        <source>About Crossfade Plugin</source>
        <translation>O wtyczce Crossfade</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="52"/>
        <source>Qmmp Crossfade Plugin</source>
        <translation>Wtyczka Crossfade dla Qmmp</translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Crossfade Plugin Settings</source>
        <translation>Ustawienia wtyczki Crossfade</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Overlap:</source>
        <translation>Nakładanie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
</context>
</TS>
